<?php
class NY_OG_Output {

	protected $_metas = array();

	public function __construct(){
		global $wpseo_og;
		remove_filter('language_attributes', array($wpseo_og, 'add_opengraph_namespace'), 11);
		remove_action('wp_head', 'jetpack_og_tags');
		add_filter('language_attributes', array($this, 'add_og_attribute'), 12);
		add_action('wp_head', array($this, 'add_og_elements'));
	}

	public function add_og_elements(){
		if (is_singular()) {
			the_post();
			$this->_metas['og:title'] = $this->_get_title();
			$this->_metas['og:url'] = get_permalink();
			$this->_metas['og:description'] = $this->_get_description();
			$this->_metas['og:type'] = $this->_get_type();
			$this->_metas['og:site_name'] = strip_tags(get_bloginfo('name'));
			$this->_metas['og:locale'] = strtolower(str_replace('-', '_', get_bloginfo('language')));

			$this->_add_image();

			$this->_output();
			rewind_posts();
		}
	}
	
	public function add_og_attribute() {
		return ' prefix="og: http://ogp.me/ns#"';
	}
	
	public function _get_title(){
		$title = null;
		if(get_post_meta(get_the_ID(), '_og_title', TRUE)){
			$title = get_post_meta(get_the_ID(), '_og_title', TRUE);
		}
		else if (function_exists('aiosp_meta')) {
			$title = trim(get_post_meta(get_the_ID(), '_aioseop_title', true));
		}
		else if (function_exists('wpseo_get_value')){
			$title = wpseo_get_value('title', get_the_ID() );
		}
		return empty($title) ? get_the_title() : $title;
	}
	
	protected function _get_type(){
		$type = null;
		if(get_post_meta(get_the_ID(), '_og_type', TRUE)){
			$type = get_post_meta(get_the_ID(), '_og_type', TRUE);
		}
		else {
			$type = 'article';
		}

		return $type;
	}

	public function _get_description(){
		$description = null;
		if(get_post_meta(get_the_ID(), '_og_description', TRUE)){
			$description = get_post_meta(get_the_ID(), '_og_description', TRUE);
		}
		else if (function_exists('aiosp_meta')) {
			$description = trim(get_post_meta(get_the_ID(), '_aioseop_description', true));
		}
		else if (function_exists('wpseo_get_value')){
			$description = wpseo_get_value('metadesc', get_the_ID() );
		}
		return empty($description) ? strip_tags(get_the_excerpt()) : $description;
	}

	public function _add_image($admin_img=false){
		if (has_post_thumbnail()) {
			$this->_metas['og:image'] = wp_get_attachment_url(get_post_thumbnail_id());
			if($admin_img) {
				$img = wp_get_attachment_image( get_post_thumbnail_id(), array(50,50) );
				return $img;
			}
			return wp_get_attachment_url(get_post_thumbnail_id());
		}
		else {
			$attachment = get_posts(array( 'numberposts' => 1, 'post_type'=>'attachment', 'post_parent' => get_the_ID() ));
			if ($attachment) {
				$this->_metas['og:image'] = wp_get_attachment_thumb_url($attachment[0]->ID);
				if($admin_img) {
					$img = wp_get_attachment_image( $attachment[0]->ID, array(50,50) );
					return $img;
				}
				return wp_get_attachment_thumb_url($attachment[0]->ID);
			}
			wp_reset_query();
		}
	}

	protected function _output(){
		echo "<!-- Open Graph Meta Data by WP-Open-Graph plugin-->\n";
		foreach ($this->_metas as $property => $content) { 
			$content = is_array($content) ? $content : array($content);
			foreach ($content as $content_single) {
				echo '<meta property="' . $property . '" content="' . esc_attr(trim($content_single)) . '" />' . "\n";
			} 
		}
		echo "<!-- /Open Graph Meta Data -->\n";
	}
}